@@ -48,7 +48,7 @@ def shortReadMapping(strainName,R1,R2,reference,outputFolder):
     outputLog=""
     #Mapping
     samFile=os.path.join(outputFolder, strainName+".sam")
-    RGline="@RG\\tID:ID_${strainName}\\tLB:LB_"+strainName+"\\tPL:ILLUMINA\\tPU:PU_"+strainName+"\\tSM:SM_"+strainName
+    RGline="@RG\\tID:ID_"+strainName+"\\tLB:LB_"+strainName+"\\tPL:ILLUMINA\\tPU:PU_"+strainName+"\\tSM:SM_"+strainName
     p=subprocess.run(["bwa","mem","-M","-R", RGline, reference, R1, R2, "-o", samFile],stderr=subprocess.PIPE,stdout=subprocess.PIPE, universal_newlines=True)
     outputLog+="COMMAND: "+" ".join(["bwa","mem","-M","-R", RGline, reference, R1, R2, "-o", samFile])+"\n\n"
     if p.stderr!="" or p.stdout !="":
@@ -94,12 +94,14 @@ def shortReadMapping(strainName,R1,R2,reference,outputFolder):
     if p.stderr!="" or p.stdout !="":
         outputLog+="STDERR:\n\n"+p.stderr+"\n\nSTDOUT:\n\n"+p.stdout+"\n\n"
 
-
-    #Cleaning up
-    os.remove(samFile)
-    os.remove(bamFile)
-    os.remove(sortedBamFile)
-    os.remove(MDsortedBamFile)
+    try:
+        #Cleaning up
+        os.remove(samFile)
+        os.remove(bamFile)
+        os.remove(sortedBamFile)
+        os.remove(MDsortedBamFile)
+    except:
+        return outputLog,"ERROR: Short reads unsuccessfully mapped to reference"
 
     return outputLog,"Short reads successfully mapped to reference"
 
@@ -151,7 +153,7 @@ def assignLongReadToSNPs(samPath,bedPath,referencePath,minQ,minMQ,minAln,outputP
     #https://davetang.org/wiki/tiki-index.php?page=SAM
 
     #QScores
-    #https://drive5.com/usearch/manual/quality_score.html
+    #https://medium.com/@robertopreste/phred-quality-score-2837415f0af
 
     #To consider:
     #Currently, softclips, insertions and padding worsen the alignment score, you might want to change that
@@ -162,7 +164,9 @@ def assignLongReadToSNPs(samPath,bedPath,referencePath,minQ,minMQ,minAln,outputP
 
     #P = 10-Q/10
 
-    QScores={"!":0,'"':1,"#":2,"$":3,"%":4,"&":5,"'":6,"(":7,")":8,"*":9,"+":10,",":11,"-":12,".":13,"/":14,"0":15,"1":16,"2":17,"3":18,"4":19,"5":20,"6":21,"7":22,"8":23,"9":24,":":25,";":26,"<":27,"=":28,">":29,"?":30,"@":31,"A":32,"B":33,"C":34,"D":35,"E":36,"F":37,"G":38,"H":39,"I":40,"J":41,"K":42} #Looks like the score is never 0 and that it's never over 30
+    QScores={}
+    for i in range(0,200):
+        QScores[chr(33+i)]=i
 
     PScores={}
 
@@ -227,7 +231,11 @@ def assignLongReadToSNPs(samPath,bedPath,referencePath,minQ,minMQ,minAln,outputP
         matchStart=False
         averageScore=0
         for Q in QLine:
-            averageScore+=QScores[Q]
+	    try:
+                averageScore+=QScores[Q]
+	    except:
+		QScores[Q]=ord(Q)-33
+		averageScore+=QScores[Q]
         averageScore=int(averageScore/len(QLine))
         #
         #Okay so now we evaluate the cigar string and just slide down the SEQ and the reference simultaneously
@@ -477,9 +485,9 @@ def simplifyDataVis(dataVisPath,simpleOutPath,distance):
     outFile.close()
 
 def generateDataVis(dataVisPath,outPath):
-    outputPNG=outputSVG=outPath+"dataVis.png"
-    outputPDF=outputSVG=outPath+"dataVis.pdf"
-    outputSVG=outputSVG=outPath+"dataVis.svg"
+    outputPNG=outPath+"dataVis.png"
+    outputPDF=outPath+"dataVis.pdf"
+    outputSVG=outPath+"dataVis.svg"
 
     tbl = pd.read_csv(dataVisPath, sep="\t", header=None)
     tbl.columns = ["contigName", "startPos", "endPos", "chr", "yValue"]
@@ -488,9 +496,9 @@ def generateDataVis(dataVisPath,outPath):
     
     g=(ggplot(tbl,aes(y=tbl["yValue"],yend=tbl["yValue"],x=tbl["startPos"],xend=tbl["endPos"],color='factor(yValue)'))+geom_segment(size=1.5)+theme(legend_position="none")+theme(panel_grid_minor=element_blank())+theme(axis_title_y=element_blank(),axis_text_y=element_blank(),axis_ticks_major_y=element_blank())+xlab("Distance from start of genome (bp)")+theme(subplots_adjust={'hspace': 0.7}))
 
+    ggsave(g,filename=outputSVG,width=18, height=10)
     ggsave(g,filename=outputPNG,width=18, height=10)
     ggsave(g,filename=outputPDF,width=18, height=10)
-    ggsave(g,filename=outputSVG,width=18, height=10)
 
     return "Generated plots"
 
